@@ -6,19 +6,19 @@ import functools
 import asyncio
 
 from graphsignal.version import __version__
-from graphsignal.agent import Agent
-from graphsignal.traces import Trace, TraceOptions
+from graphsignal.tracer import Tracer
+from graphsignal.spans import Span, TraceOptions, get_current_span
 
 logger = logging.getLogger('graphsignal')
 
-_agent = None
+_tracer = None
 
 
 def _check_configured():
-    global _agent
-    if not _agent:
+    global _tracer
+    if not _tracer:
         raise ValueError(
-            'Agent not configured, call graphsignal.configure() first')
+            'Tracer not configured, call graphsignal.configure() first')
 
 
 def _check_and_set_arg(
@@ -56,123 +56,136 @@ def configure(
         deployment: Optional[str] = None,
         tags: Optional[Dict[str, str]] = None,
         auto_instrument: Optional[bool] = True,
+        record_data_samples: Optional[bool] = True,
         upload_on_shutdown: Optional[bool] = True,
         debug_mode: Optional[bool] = False) -> None:
-    global _agent
+    global _tracer
 
-    if _agent:
-        logger.warning('Agent already configured')
+    if _tracer:
+        logger.warning('Tracer already configured')
         return
 
     debug_mode = _check_and_set_arg('debug_mode', debug_mode, is_bool=True)
-    if debug_mode:
-        logger.setLevel(logging.DEBUG)
-    else:
-        logger.setLevel(logging.WARNING)
     api_key = _check_and_set_arg('api_key', api_key, is_str=True, required=True)
     api_url = _check_and_set_arg('api_url', api_url, is_str=True, required=False)
     deployment = _check_and_set_arg('deployment', deployment, is_str=True, required=True)
     tags = _check_and_set_arg('tags', tags, is_kv=True, required=False)
 
-    _agent = Agent(
+    _tracer = Tracer(
         api_key=api_key,
         api_url=api_url,
         deployment=deployment,
         tags=tags,
         auto_instrument=auto_instrument,
+        record_data_samples=record_data_samples,
         upload_on_shutdown=upload_on_shutdown,
         debug_mode=debug_mode)
-    _agent.setup()
+    _tracer.setup()
 
     atexit.register(shutdown)
 
-    logger.debug('Agent configured')
+    logger.debug('Tracer configured')
 
 
 def set_tag(key: str, value: str) -> None:
     _check_configured()
 
     if not key:
-        raise ValueError('set_tag: key must be provided')
+        logger.error('set_tag: key must be provided')
+        return
+
     if value is None:
-        raise ValueError('set_tag: value must be provided')
+        _tracer.tags.pop(key, None)
+        return
 
-    if _agent.tags is None:
-        _agent.tags = {}
+    if len(_tracer.tags) > Span.MAX_RUN_TAGS:
+        logger.error('set_tag: too many tags (>{0})'.format(Span.MAX_RUN_TAGS))
+        return
 
-    if len(_agent.tags) > Trace.MAX_RUN_TAGS:
-        raise ValueError('set_tag: too many tags (>{0})'.format(Trace.MAX_RUN_TAGS))
-
-    _agent.tags[key] = value
+    _tracer.tags[key] = value
 
 
-def log_param(name: str, value: str) -> None:
-    if not name:
-        raise ValueError('set_param: name must be provided')
+def set_context_tag(key: str, value: str) -> None:
+    _check_configured()
+
+    if not key:
+        logger.error('set_context_tag: key must be provided')
+        return
+
+    tags = _tracer.context_tags.get()
+
     if value is None:
-        raise ValueError('set_param: value must be provided')
+        tags.pop(key, None)
+        _tracer.context_tags.set(tags)
+        return
 
-    if _agent.params is None:
-        _agent.params = {}
+    if len(tags) > Span.MAX_RUN_TAGS:
+        logger.error('set_context_tag: too many tags (>{0})'.format(Span.MAX_RUN_TAGS))
+        return
 
-    if len(_agent.params) > Trace.MAX_RUN_PARAMS:
-        raise ValueError('set_param: too many params (>{0})'.format(Trace.MAX_RUN_PARAMS))
-
-    _agent.params[name] = value
+    tags[key] = value
+    _tracer.context_tags.set(tags)
 
 
 def start_trace(
-        endpoint: str,
+        operation: str,
         tags: Optional[Dict[str, str]] = None,
-        options: Optional[TraceOptions] = None) -> Trace:
+        options: Optional[TraceOptions] = None) -> 'Span':
     _check_configured()
 
-    return Trace(endpoint=endpoint, tags=tags, options=options)
+    return Span(operation=operation, tags=tags, options=options)
 
 
 def trace_function(
-        func=None, *,
-        endpoint: Optional[str] = None,
+        func=None, 
+        *,
+        operation: Optional[str] = None,
         tags: Optional[Dict[str, str]] = None,
         options: Optional[TraceOptions] = None):
     if func is None:
-        return functools.partial(trace_function, endpoint=endpoint, tags=tags, options=options)
+        return functools.partial(trace_function, operation=operation, tags=tags, options=options)
 
-    if endpoint is None:
-        endpoint_or_name = func.__name__
+    if operation is None:
+        operation_or_name = func.__name__
     else:
-        endpoint_or_name = endpoint
+        operation_or_name = operation
 
     if asyncio.iscoroutinefunction(func):
         @functools.wraps(func)
         async def tf_async_wrapper(*args, **kwargs):
-            with start_trace(endpoint=endpoint_or_name, tags=tags, options=options):
+            async with start_trace(operation=operation_or_name, tags=tags, options=options):
                 return await func(*args, **kwargs)
         return tf_async_wrapper
     else:
         @functools.wraps(func)
         def tf_wrapper(*args, **kwargs):
-            with start_trace(endpoint=endpoint_or_name, tags=tags, options=options):
+            with start_trace(operation=operation_or_name, tags=tags, options=options):
                 return func(*args, **kwargs)
         return tf_wrapper
 
 
+def current_span() -> Optional['Span']:
+    _check_configured()
+
+    return get_current_span()
+
+
 def upload(block=False) -> None:
     _check_configured()
 
-    _agent.upload(block=block)
+    _tracer.upload(block=block)
 
 
 def shutdown() -> None:
-    global _agent
-    if not _agent:
+    global _tracer
+    if not _tracer:
         return
 
     atexit.unregister(shutdown)
-    _agent.shutdown()
-    _agent = None
+    _tracer.shutdown()
+    _tracer = None
 
-    logger.debug('Agent shutdown')
+    logger.debug('Tracer shutdown')
 
 
 __all__ = [
@@ -182,6 +195,7 @@ __all__ = [
     'shutdown',
     'start_trace',
     'function_trace',
-    'Trace',
-    'TraceOptions'
+    'TraceOptions',
+    'Span',
+    'callbacks'
 ]
\ No newline at end of file
