@@ -9,14 +9,15 @@ from graphsignal.data.tf_tensor import TFTensorProfiler
 from graphsignal.data.torch_tensor import TorchTensorProfiler
 from graphsignal.data.base_data_profiler import DataStats
 
+
 logger = logging.getLogger('graphsignal')
 
 
 data_profilers = [
-    BuiltInTypesProfiler(),
     NumpyNDArrayProfiler(),
     TorchTensorProfiler(),
-    TFTensorProfiler()
+    TFTensorProfiler(),
+    BuiltInTypesProfiler()
 ]
 
 
@@ -25,4 +26,10 @@ def compute_data_stats(data):
         if dp.is_instance(data):
             return dp.compute_stats(data)
 
-    return DataStats(type_name=type(data).__name__)
+
+def encode_data_sample(data):
+    for dp in data_profilers:
+        if dp.is_instance(data):
+            return dp.encode_sample(data)
+
+    return None
