@@ -10,18 +10,14 @@ class BaseRecorder(ABC):
     def shutdown(self):
         pass
 
-    @abstractmethod
-    def on_trace_start(self, proto, context, options):
+    def on_span_start(self, proto, context, options):
         pass
 
-    @abstractmethod
-    def on_trace_stop(self, proto, context, options):
+    def on_span_stop(self, proto, context, options):
         pass
 
-    @abstractmethod
-    def on_trace_read(self, proto, context, options):
+    def on_span_read(self, proto, context, options):
         pass
 
-    @abstractmethod
     def on_metric_update(self):
         pass
