@@ -1,53 +1,48 @@
 import logging
 import os
-import json
-import re
+import sys
 import cProfile, pstats
+import threading
 
 import graphsignal
 from graphsignal.recorders.base_recorder import BaseRecorder
 from graphsignal.proto_utils import parse_semver
 from graphsignal.proto import signals_pb2
-from graphsignal.proto_utils import add_framework_param
+from graphsignal.proto_utils import add_library_param
 
 logger = logging.getLogger('graphsignal')
 
 class CProfileRecorder(BaseRecorder):
     def __init__(self):
+        self._profiler_lock = threading.Lock()
         self._profiler = None
         self._exclude_path = os.path.dirname(os.path.realpath(graphsignal.__file__))
 
-    def setup(self):
-        pass
-
-    def on_trace_start(self, proto, context, options):
+    def on_span_start(self, proto, context, options):
         if not options.enable_profiling:
             return
+        if not self._profiler_lock.acquire(blocking=False):
+            return
+        if 'torch' in sys.modules or 'yappi' in sys.modules:
+            return
 
         self._profiler = cProfile.Profile()
         self._profiler.enable()
+        context['is_cprofile_profiling'] = True
 
-    def on_trace_stop(self, proto, context, options):
-        if not options.enable_profiling:
-            return
-
-        if not self._profiler:
+    def on_span_stop(self, proto, context, options):
+        if not context.get('is_cprofile_profiling', False):
             return
 
         self._profiler.disable()
         
-    def on_trace_read(self, proto, context, options):
-        if not options.enable_profiling:
-            return
-
-        if not self._profiler:
+    def on_span_read(self, proto, context, options):
+        if not context.get('is_cprofile_profiling', False):
             return
 
         self._convert_to_profile(proto)
         self._profiler = None
-
-    def on_metric_update(self):
-        pass
+        self._profiler_lock.release()
 
     def _convert_to_profile(self, proto):
         stats = pstats.Stats(self._profiler)
@@ -77,6 +72,8 @@ class CProfileRecorder(BaseRecorder):
             if total_tt > 0:
                 op_stats.self_host_time_percent = tt / total_tt * 100
 
+        proto.labels.append('profiled')
+
     def _has_exclude_func(self, stats, func_key, visited):
         if func_key in visited:
             return visited[func_key]
