@@ -1,26 +1,26 @@
 import logging
 import sys
 import torch
-import torch.distributed as dist
+import threading
 
 import graphsignal
 from graphsignal.recorders.base_recorder import BaseRecorder
 from graphsignal.proto_utils import parse_semver
 from graphsignal.proto import signals_pb2
-from graphsignal.proto_utils import add_framework_param, add_driver
+from graphsignal.proto_utils import add_library_param, add_driver
 
 logger = logging.getLogger('graphsignal')
 
 class KinetoRecorder(BaseRecorder):
     def __init__(self):
         self._torch_prof = None
+        self._profiler_lock = threading.Lock()
 
-    def setup(self):
-        pass
-
-    def on_trace_start(self, proto, context, options):
+    def on_span_start(self, proto, context, options):
         if not options.enable_profiling:
             return
+        if not self._profiler_lock.acquire(blocking=False):
+            return
 
         if not self._torch_prof:
             def _schedule_func(step):
@@ -33,15 +33,16 @@ class KinetoRecorder(BaseRecorder):
                 with_flops=True)
 
         self._torch_prof.start()
+        context['is_kineto_profiling'] = True
 
-    def on_trace_stop(self, proto, context, options):
-        if not options.enable_profiling:
+    def on_span_stop(self, proto, context, options):
+        if not context.get('is_kineto_profiling', False):
             return
 
         self._torch_prof.stop()
 
-    def on_trace_read(self, proto, context, options):
-        if not options.enable_profiling:
+    def on_span_read(self, proto, context, options):
+        if not context.get('is_kineto_profiling', False):
             return
 
         total_self_host_time_ns = 0
@@ -86,8 +87,10 @@ class KinetoRecorder(BaseRecorder):
         for kernel_stats in kernel_index.values():
             proto.kernel_profile.append(kernel_stats)
 
-    def on_metric_update(self):
-        pass
+        proto.labels.append('profiled')
+
+        self._profiler_lock.release()
+
 
 def _ns(val):
     return int(max(val, 0) * 1e3)
